function [] = basic_figs(CPT_num)

% This function may be used for quickly viewing the primary data (qt, fs,
% u2) in any of the CSV data files. This file should be saved in the same
% directory as the data files. It can be executed by typing
% 'basic_figs(nnn)' at the MATLAB command line, where nnn = the cone
% sounding number [201,222].
%
% Note that this function does no error checking, so it is the user's
% responsibility to ensure that the inputs (sounding number and data) are
% reasonable.
%
% T. Matthew Evans
% Oregon State University
% School of Civil and Construction Engineering
% rev0: 02/09/2024
% rev1: 06/03/2024

% Read data file
fname = ['PacWave_CPT-' num2str(CPT_num) '.csv'];
M = readmatrix(fname,'NumHeaderLines',10);

% Create three plots
subplot(1,3,1)
plot(M(:,2),M(:,1));
axis ij
xlabel('Tip Resistance, q_t [MPa]');
ylabel('Depth, z [m]');
set(gca,'XAxisLocation','top')

subplot(1,3,2)
plot(M(:,3),M(:,1),'r');
axis ij
xlabel('Sleeve Friction, f_s [MPa]');
set(gca,'XAxisLocation','top')

subplot(1,3,3)
plot(M(:,4),M(:,1),'g');
axis ij
xlabel('Pore Water Pressure, u_2 [kPa]');
set(gca,'XAxisLocation','top')

sgtitle(['PacWave CPT-' num2str(CPT_num)])