# basic_figs(CPT_num): visualize CPT data from CSV files

# Example usage:
# basic_figs(nnn)  where nnn is the desired CPT number

# This function may be used for quickly viewing the primary data (qt, fs,
# u2) in any of the CSV data files. This file should be saved in the same
# directory as the data files. It can be executed by typing
# 'basic_figs(nnn)' at the MATLAB command line, where nnn = the cone
# sounding number [201,222].
#
# Note that this function does no error checking, so it is the user's
# responsibility to ensure that the inputs (sounding number and data) are
# reasonable.
#
# T. Matthew Evans
# Oregon State University
# School of Civil and Construction Engineering
# Ported from MATLAB (rev0: 02/09/2024)
# rev1: 06/03/2024

import pandas as pd
import matplotlib.pyplot as plt

def basic_figs(CPT_num):
    # Read data file
    fname = f'PacWave_CPT-{CPT_num}.csv'
    M = pd.read_csv(fname, skiprows=10).values

    # Create three plots
    fig, axs = plt.subplots(1, 3, figsize=(10, 10))

    axs[0].plot(M[:, 1], M[:, 0])
    axs[0].invert_yaxis()
    axs[0].set_xlabel('$Tip Resistance, q_t [MPa]$')
    axs[0].set_ylabel('Depth, z [m]')
    axs[0].xaxis.set_ticks_position('top')
    axs[0].xaxis.set_label_position('top')

    axs[1].plot(M[:, 2], M[:, 0], 'r')
    axs[1].invert_yaxis()
    axs[1].set_xlabel('$Sleeve Friction, f_s [MPa]$')
    axs[1].xaxis.set_ticks_position('top')
    axs[1].xaxis.set_label_position('top')

    axs[2].plot(M[:, 3], M[:, 0], 'g')
    axs[2].invert_yaxis()
    axs[2].set_xlabel('$Pore Water Pressure, u_2 [kPa]$')
    axs[2].xaxis.set_ticks_position('top')
    axs[2].xaxis.set_label_position('top')

    fig.suptitle(f'PacWave CPT-{CPT_num}')
    plt.show()

